[−][src]Macro google_authenticator::create_secret
A macro that can be used for convenient access to the function
GoogleAuthenticator::create_secret, by providing a default of 32 to the length parameter.
A macro that can be used for convenient access to the function
GoogleAuthenticator::create_secret, by providing a default of 32 to the length parameter.