[][src]Macro google_authenticator::get_code

macro_rules! get_code {
    ($secret: expr, $time_slice: expr) => { ... };
    ($secret: expr) => { ... };
}

A macro that can be used for convenient access to the function GoogleAuthenticator::create_secret, by providing a default of the current time to the times_slice parameter.