[−][src]Macro google_authenticator::get_code
A macro that can be used for convenient access to the function
GoogleAuthenticator::create_secret, by providing a default of the current time to the
times_slice parameter.
A macro that can be used for convenient access to the function
GoogleAuthenticator::create_secret, by providing a default of the current time to the
times_slice parameter.